import React from 'react';
import {
  Title,
  Description,
  Primary,
  Stories,
  PRIMARY_STORY,
  ArgsTable,
} from '@storybook/addon-docs/blocks';

import Anchor from '.';
import styles from './anchor.module.scss';

export default {
  title: 'Theme/Modules/Anchor/Template One',
  component: Anchor,
  argTypes: {
    module: {
      name: 'module',
      type: { name: 'object', required: false },
      defaultValue: '',
      description: 'The module data object including list of sections.',
      table: {
        type: { summary: 'object' },
        defaultValue: { summary: null },
      },
    },
    headerOffset: {
      name: 'headerOffset',
      type: { name: 'number', required: false },
      defaultValue: 0,
      description: 'The space between the header and target section in pixels.',
      table: {
        type: { summary: 'number' },
        defaultValue: { summary: 0 },
      },
    },
    sliderGap: {
      name: 'sliderGap',
      type: { name: 'number', required: false },
      defaultValue: 0,
      description: 'The space between navigation buttons in pixels.',
      table: {
        type: { summary: 'number' },
        defaultValue: { summary: 0 },
      },
      control: null,
    },
  },
  parameters: {
    docs: {
      description: {
        component:
          'A component that generates some label items, and the user can navigate inside a page by clicking on them, takes the user to specific parts of the page',
      },
      page: () => (
        <>
          <Title />
          <Description />
          <Primary />
          <Stories />
          <ArgsTable story={PRIMARY_STORY} />
        </>
      ),
    },
  },
};

const Template = (args) => (
  <>
    <Anchor {...args} />
    <div id="sectionone" className={styles.storyDivs}>
      <h2>section one</h2>
      <p>
        Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has
        been the industry's standard dummy text ever since the 1500s, when an unknown printer took a
        galley of type and scrambled it to make a type specimen book. It has survived not only five
        centuries, but also the leap into electronic typesetting, remaining essentially unchanged.
        It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum
        passages, and more recently with desktop publishing software like Aldus PageMaker including
        versions of Lorem Ipsum.
      </p>
    </div>
    <div id="sectiontwo" className={styles.storyDivs}>
      <h2>section two</h2>
      <p>
        Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has
        been the industry's standard dummy text ever since the 1500s, when an unknown printer took a
        galley of type and scrambled it to make a type specimen book. It has survived not only five
        centuries, but also the leap into electronic typesetting, remaining essentially unchanged.
        It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum
        passages, and more recently with desktop publishing software like Aldus PageMaker including
        versions of Lorem Ipsum.
      </p>
    </div>
    <div id="sectionthree" className={styles.storyDivs}>
      <h2>section three</h2>
      <p>
        Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has
        been the industry's standard dummy text ever since the 1500s, when an unknown printer took a
        galley of type and scrambled it to make a type specimen book. It has survived not only five
        centuries, but also the leap into electronic typesetting, remaining essentially unchanged.
        It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum
        passages, and more recently with desktop publishing software like Aldus PageMaker including
        versions of Lorem Ipsum.
      </p>
    </div>
  </>
);

export const Default = Template.bind({});
Default.args = {
  module: {
    items: [{ label: 'section one' }, { label: 'section two' }, { label: 'section three' }],
  },
  sliderGap: 10,
  headerOffset: 0,
};
